AppInstanceArgs

Struct AppInstanceArgs 

pub struct AppInstanceArgs {
    pub timestamp: DInstant,
    pub args: Box<[Txt]>,
    pub count: usize,
    pub propagation: EventPropagationHandle,
}
Arguments for APP_INSTANCE_EVENT.

Fields

timestamp: DInstant

Instant the event happened.

args: Box<[Txt]>

Arguments the app instance was started with.

See std::env::args for more details.

count: usize

Instance count. Is zero for the current process, in single instance mode increments for each subsequent attempt to instantiate the app.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl AppInstanceArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, args: impl Into<Box<[Txt]>>, count: impl Into<usize>, ) -> Self

New args from values that convert into the argument types.

pub fn now(args: impl Into<Box<[Txt]>>, count: impl Into<usize>) -> Self

Arguments for event that happened now (INSTANT.now).

Source

impl AppInstanceArgs

pub fn is_current(&self) -> bool

If the arguments are for the currently executing process (main).

This is only true once, on the first event on startup.