pub struct AppInstanceArgs {
pub timestamp: DInstant,
pub args: Box<[Txt]>,
pub count: usize,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for APP_INSTANCE_EVENT.
Fields
timestamp: DInstantInstant the event happened.
args: Box<[Txt]>Arguments the app instance was started with.
See std::env::args for more details.
count: usizeInstance count. Is zero for the current process, in single instance mode increments for each subsequent attempt to instantiate the app.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl AppInstanceArgs
impl AppInstanceArgs
Sourceimpl AppInstanceArgs
impl AppInstanceArgs
Sourcepub fn is_current(&self) -> bool
pub fn is_current(&self) -> bool
If the arguments are for the currently executing process (main).
This is only true once, on the first event on startup.